@@ -2,6 +2,8 @@ test_that("plot for exponential fit", {
   expect_snapshot(
     suppressMessages( # because the progress bar is messing with check()
       flux_plot(slopes0_flag,
+        conc,
+        datetime,
         f_plotname = "test_exp_plot",
         print_plot = FALSE,
         output = "pdfpages"
@@ -16,7 +18,7 @@ test_that("plot for linear fit", {
   expect_snapshot(
     vdiffr::expect_doppelganger(
       "plot for linear fit",
-      flux_plot(slopes30lin_flag)
+      flux_plot(slopes30lin_flag, conc, datetime)
     )
   )
 })
@@ -25,6 +27,8 @@ test_that("plot for linear fit with jpg extension works", {
   expect_snapshot(
     suppressMessages( # because the progress bar is messing with check()
       flux_plot(slopes30lin_flag,
+        conc,
+        datetime,
         f_plotname = "test_lin_plot",
         print_plot = FALSE,
         output = "ggsave",
@@ -37,6 +41,6 @@ test_that("plot for linear fit with jpg extension works", {
 })
 
 test_that("plot can be exported as an object", {
-  plot_object <- flux_plot(slopes30lin_flag)
+  plot_object <- flux_plot(slopes30lin_flag, conc, datetime)
   vdiffr::expect_doppelganger("plot as an object", plot_object)
 })
